using System;
using System.Collections.Generic;


namespace PrintPreviewer
{
    public enum PageOrientation
    {
        Portrait = 1,
        Landscape = 2
    }

    public class DocumentProperties
    {
        #region Fields

        private string m_sDocumentName;
        private string m_sDeviceName;
        private int m_iPrintJobId;
        private string m_sMachineName;
        private string m_sUserName;
        private int m_iSessionId;
        private int m_iHorizontalResolution;
        private int m_iVerticalResolution;
        private PageOrientation m_PageOrientation;
        private int m_iPaperSize;
        private string m_sPaperSizeName;
        private int m_iPaperWidth;
        private int m_iPaperLength;
        private int m_iPagesQuantity;
        private int m_iCopiesQuantity;
        private int m_iPaperBin;
        private string m_sPaperBinName;
        private bool m_bCollate;
        private List<string> m_Files = new List<string>();

        #endregion

        #region Properties

        public string Name
        {
            get { return m_sDocumentName; }
            set { m_sDocumentName = value; }
        }

        public string MachineName
        {
            get { return m_sMachineName; }
            set { m_sMachineName = value; }
        }

        public string UserName
        {
            get { return m_sUserName; }
            set { m_sUserName = value; }
        }

        public int SessionID
        {
            get { return m_iSessionId; }
            set { m_iSessionId = value; }
        }

        public int JobID
        {
            get { return m_iPrintJobId; }
            set { m_iPrintJobId = value; }
        }

        public int HorizontalResolution
        {
            get { return m_iHorizontalResolution; }
            set { m_iHorizontalResolution = value; }
        }

        public int VerticalResolution
        {
            get { return m_iVerticalResolution; }
            set { m_iVerticalResolution = value; }
        }

        public PageOrientation Orientation
        {
            get { return m_PageOrientation; }
            set { m_PageOrientation = value; }
        }

        public int PaperSize
        {
            get { return m_iPaperSize; }
            set { m_iPaperSize = value; }
        }

        public string PaperSizeName
        {
            get { return m_sPaperSizeName; }
            set { m_sPaperSizeName = value; }
        }

        public int PaperWidth
        {
            get { return m_iPaperWidth; }
            set { m_iPaperWidth = value; }
        }

        public int PaperLength
        {
            get { return m_iPaperLength; }
            set { m_iPaperLength = value; }
        }

        public int Pages
        {
            get { return m_iPagesQuantity; }
            set { m_iPagesQuantity = value; }
        }

        public int Copies
        {
            get { return m_iCopiesQuantity; }
            set { m_iCopiesQuantity = value; }
        }

        public int Bin
        {
            get { return m_iPaperBin; }
            set { m_iPaperBin = value; }
        }

        public string BinName
        {
            get { return m_sPaperBinName; }
            set { m_sPaperBinName = value; }
        }

        public bool Collate
        {
            get { return m_bCollate; }
            set { m_bCollate = value; }
        }

        public List<string> Files
        {
            get { return m_Files; }
        }

        #endregion

        //Constructor, simply zeroes class members
        public DocumentProperties()
        {
            ClearAll(false);
        }

        // This function parses the specified .ini file and fills class members
        public bool Retrieve(string sIniFileName)
        {
            ClearAll(true);

            IniFile Ini = new IniFile(String.Empty);
            if (Ini.SetFileName(sIniFileName) == false)
                return false;

            m_sDeviceName = Ini.IniReadValue("Device", "DeviceName", "Unknown");
            m_sDocumentName = Ini.IniReadValue("Document", "Name", "");
            m_iPrintJobId = int.Parse(Ini.IniReadValue("Document", "JobID", "0"));
            m_sMachineName = Ini.IniReadValue("Document", "MachineName", "");
            m_sUserName = Ini.IniReadValue("Document", "UserName", "");
            m_iSessionId = int.Parse(Ini.IniReadValue("Document", "SessionID", "0"));
            m_iHorizontalResolution = int.Parse(Ini.IniReadValue("Document", "HorizontalResolution", "0"));
            m_iVerticalResolution = int.Parse(Ini.IniReadValue("Document", "VerticalResolution", "0"));
            m_PageOrientation = (PageOrientation)int.Parse(Ini.IniReadValue("Document", "Orientation", "1"));
            m_iPaperSize = int.Parse(Ini.IniReadValue("Document", "PaperSize", "0"));
            m_sPaperSizeName = Ini.IniReadValue("Document", "PaperSizeName", "Unknown");
            m_iPaperWidth = int.Parse(Ini.IniReadValue("Document", "PaperWidth", "0"));
            m_iPaperLength = int.Parse(Ini.IniReadValue("Document", "PaperLength", "0"));
            m_iPagesQuantity = int.Parse(Ini.IniReadValue("Document", "Pages", "0"));
            m_iCopiesQuantity = int.Parse(Ini.IniReadValue("Document", "Copies", "0"));
            m_bCollate = (int.Parse(Ini.IniReadValue("Document", "Collate", "0")) != 0);
            m_iPaperBin = int.Parse(Ini.IniReadValue("Document", "Bin", "0"));
            m_sPaperBinName = Ini.IniReadValue("Document", "BinName", "Unknown");

            string s;
            for (int i = 0; i < m_iPagesQuantity; i++)
            {
                s = String.Format("File{0}", i);
                m_Files.Add(Ini.IniReadValue("EMF", s, ""));
            }

            return true;
        }

        // This function sets all parameters to zero or empty string
        public void ClearAll(bool doClearStrings)
        {
            if (doClearStrings)
            {
                m_sDeviceName = String.Empty;
                m_sDocumentName = String.Empty;
                m_sMachineName = String.Empty;
                m_sUserName = String.Empty;
                m_sPaperSizeName = String.Empty;
                m_sPaperBinName = String.Empty;
                m_Files.Clear();
            }

            m_iPrintJobId = m_iSessionId = 0;
            m_iHorizontalResolution = m_iVerticalResolution = 0;
            m_iPaperSize = m_iPaperWidth = m_iPaperLength = 0;
            m_iPagesQuantity = m_iCopiesQuantity = 0;
            m_iPaperBin = 0;

            m_PageOrientation = PageOrientation.Portrait;
            m_bCollate = false;
        }
    }
}




