using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Imaging;
using System.Text;
using System.Windows.Forms;

namespace PrintPreviewer
{
    public partial class PrintPreviwer : Form
    {
        private int m_currentPage = -1;
        private string m_commandLine = String.Empty;
        private DocumentProperties m_docProps = new DocumentProperties();


        public PrintPreviwer(string commandLine)
        {
            InitializeComponent();

            // Initialize members
            m_pictureBox.Image = null;
            m_commandLine = commandLine;
        }

        #region Control Handlers

        private void PrintPreviwer_Load(object sender, EventArgs e)
        {
            // Parse .ini file
            if (!m_docProps.Retrieve(m_commandLine))
            {
                m_listBox.Items.Add("Invalid command line parameter!");
            }
            else
            {
                // Fill in the ListBox
                fillListBox();

                // Load 1st page preview
                if (m_docProps.Files.Count > 0)
                    loadPreview(0);
            }
        }

        private void m_pictureBox_DoubleClick(object sender, EventArgs e)
        {
            try
            {
                // Open page preview with the default application
                System.Diagnostics.Process.Start(m_docProps.Files[m_currentPage]);
            }
            catch
            {
            }
        }

        private void m_listBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                // If the clicked item of the listbox corresponds to a printed page
                // then appropriate .emf file will be opened on the preview panel
                loadPreview(m_listBox.SelectedIndex - (int)m_listBox.Tag);
            }
            catch
            {
            }
        }

        private void m_pictureBox_Paint(object sender, PaintEventArgs e)
        {
            // Draw string "No image" on preview panel if there are not images
            if (m_commandLine == String.Empty)
            {
                // Create font and brush.
                Font font = new Font("Arial", 12, FontStyle.Bold);
                SolidBrush brush = new SolidBrush(Color.Black);

                // Set format of string.
                StringFormat stringFormat = new StringFormat();
                stringFormat.LineAlignment = StringAlignment.Center;
                stringFormat.Alignment = StringAlignment.Center;

                Rectangle rect = m_pictureBox.ClientRectangle;

                e.Graphics.DrawString("No image", font, brush, rect, stringFormat);
            }
        }

        private void m_buttonClose_Click(object sender, EventArgs e)
        {
            Close();
        }

        #endregion

        // This functions fills in the ListBox (print job details)
        private void fillListBox()
        {
            m_listBox.BeginUpdate();
            m_listBox.Items.Add("Document name: " + m_docProps.Name);
            string str = String.Format("Print job ID: {0}", m_docProps.JobID);
            m_listBox.Items.Add(str);
            m_listBox.Items.Add("");

            str = String.Format("Horizontal resolution: {0} dpi", m_docProps.HorizontalResolution);
            m_listBox.Items.Add(str);
            str = String.Format("Vertical resolution: {0} dpi", m_docProps.VerticalResolution);
            m_listBox.Items.Add(str);
            m_listBox.Items.Add("");

            str = String.Format("Paper size: {0} ({1} x {2} mm)", m_docProps.PaperSizeName, m_docProps.PaperWidth/10, m_docProps.PaperLength/10);
            m_listBox.Items.Add(str);
            m_listBox.Items.Add("Paper bin: " + m_docProps.BinName);
            m_listBox.Items.Add("Orientation: " + ((m_docProps.Orientation == PageOrientation.Portrait) ? "Portrait" : "Landscape"));
            m_listBox.Items.Add("");

            str = String.Format("Pages: {0}", m_docProps.Pages);
            m_listBox.Items.Add(str);
            str = String.Format("Copies: {0}", m_docProps.Copies);
            m_listBox.Items.Add(str);
            m_listBox.Items.Add("Collate: " + (m_docProps.Collate ? "Yes" : "No"));
            m_listBox.Items.Add("");

            if (m_docProps.Files.Count == 0)
                m_listBox.Items.Add("There are no printed pages");
            else
            {
                m_listBox.Items.Add("Printed pages (click to preview):");
                for (int i = 0; i < m_docProps.Files.Count; i++)
                {
                    // Add file name to the list
                    System.IO.FileInfo file = new System.IO.FileInfo(m_docProps.Files[i]);
                    str = String.Format("    Page {0}: {1}", i + 1, file.Name);
                    int x = m_listBox.Items.Add(str);

                    // Select 1st page in the list
                    if (i == 0)
                    {
                        m_listBox.SelectedIndex = x;
                        m_listBox.Tag = x;
                    }
                }
            }
            m_listBox.EndUpdate();
        }

        // This function loads the specified page to the preview panel
        private void loadPreview(int pageIndex)
        {
            Metafile metafile = null;

            if (pageIndex >= 0)
                metafile = new Metafile(m_docProps.Files[pageIndex]);

            if (metafile == null)
            {
                m_currentPage = -1;
            }
            else
            {
                m_pictureBox.Image = metafile;

                m_currentPage = pageIndex;

                // Update preview's label
                string s;
                s = String.Format("Page preview (page {0}):", pageIndex + 1);
                m_previewLabel.Text = s;
            }
        }
    }
}